/* === This file is part of Calamares - <https://calamares.io> ===
 *
 *   SPDX-FileCopyrightText: 2015 Anke Boersma <demm@kaosx.us>
 *   SPDX-FileCopyrightText: 2015 Alexandre Arnt <qtgzmanager@gmail.com>
 *   SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
 *   SPDX-FileCopyrightText: 2018 Adriaan de Groot <groot@kde.org>
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 *   Calamares is Free Software: see the License-Identifier above.
 *
 */

#include "LicenseWidget.h"

#include "utils/Logger.h"
#include "utils/QtCompat.h"

#include <QDesktopServices>
#include <QFile>
#include <QHBoxLayout>
#include <QLabel>
#include <QPushButton>
#include <QVBoxLayout>

static QString
loadLocalFile( const QUrl& u )
{
    if ( !u.isLocalFile() )
    {
        return QString();
    }

    QFile file( u.path() );
    if ( !file.open( QIODevice::ReadOnly | QIODevice::Text ) )
    {
        cWarning() << "Could not load license file" << u.path();
        return QString();
    }

    return QString( "\n" ) + file.readAll();
}

LicenseWidget::LicenseWidget( LicenseEntry entry, QWidget* parent )
    : QWidget( parent )
    , m_entry( std::move( entry ) )
    , m_label( new QLabel( this ) )
    , m_licenceTextLabel( new QLabel( this ) )
{
    QPalette pal( palette() );
    pal.setColor( WindowBackground, palette().window().color().lighter( 108 ) );

    setObjectName( "licenseItem" );

    setAutoFillBackground( true );
    setPalette( pal );
    setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Minimum );
    setContentsMargins( 4, 4, 4, 4 );

    QVBoxLayout* vLayout = new QVBoxLayout;
    QWidget* topPart = new QWidget( this );
    topPart->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
    vLayout->addWidget( topPart );

    QHBoxLayout* wiLayout = new QHBoxLayout;
    topPart->setLayout( wiLayout );

    m_licenceTextLabel->setStyleSheet( "border-top: 1px solid black; margin-top: 0px; padding-top: 1em;" );
    m_licenceTextLabel->setObjectName( "licenseItemFullText" );

    m_fullTextContents = loadLocalFile( m_entry.m_url );
    showLocalLicenseText();
    m_licenceTextLabel->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
    m_licenceTextLabel->setHidden(false);

    vLayout->addWidget( m_licenceTextLabel );
    setLayout( vLayout );
}

LicenseWidget::~LicenseWidget() {}

void
LicenseWidget::showLocalLicenseText()
{
    m_licenceTextLabel->setText( m_fullTextContents );
}
