/* === This file is part of Calamares - <https://calamares.io> ===
 *
 *   SPDX-FileCopyrightText: 2014 Teo Mrnjavac <teo@kde.org>
 *   SPDX-FileCopyrightText: 2019 Adriaan de Groot <groot@kde.org>
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 *   Calamares is Free Software: see the License-Identifier above.
 *
 */

#ifndef WELCOMEPAGE_H
#define WELCOMEPAGE_H

#include "locale/TranslationsModel.h"

#include <QStyledItemDelegate>
#include <QWidget>

namespace Ui
{
class WelcomePage;
}  // namespace Ui

class CheckerContainer;
class Config;
class WelcomePage : public QWidget
{
    Q_OBJECT
public:
    WelcomePage( Config* config, QWidget* parent = nullptr );

    enum class Button
    {
        Support,
        Donate,
        KnownIssues,
        ReleaseNotes
    };

    /// @brief Configure the button @p n, to open @p url
    void setupButton( Button b, const QString& url );


    /// @brief Results of requirements checking
    bool verdict() const;

    QString selectedSku() const;

    /// @brief Change the language from an external source.
    void externallySelectedLanguage( int row );

    void init();

public slots:
    void retranslate();

protected:
    void initSkus();
    void focusInEvent( QFocusEvent* e ) override;  //choose the child widget to focus

private:
    bool checkVerityReadOnlyRoot( const QString &fileName );

    Ui::WelcomePage* ui;
    CheckerContainer* m_checkingWidget;
    Calamares::Locale::TranslationsModel* m_languages;

    Config* m_conf;
};

#endif  // WELCOMEPAGE_H
